API Reference
=============

The pages in this section are generated from the docstrings in the
``etlplus`` package and its public modules.

.. autosummary::
   :toctree: generated

   etlplus
   etlplus.__version__
   etlplus.api.auth
   etlplus.api.config
   etlplus.api.endpoint_client
   etlplus.api.enums
   etlplus.api.pagination.client
   etlplus.api.pagination.config
   etlplus.api.pagination.paginator
   etlplus.api.rate_limiting.rate_limiter
   etlplus.api.retry_manager
   etlplus.api.transport
   etlplus.api.types
   etlplus.api.utils
   etlplus.cli.main
   etlplus.config
   etlplus.connector.api
   etlplus.connector.core
   etlplus.connector.database
   etlplus.connector.enums
   etlplus.connector.file
   etlplus.connector.utils
   etlplus.database.ddl
   etlplus.database.engine
   etlplus.database.orm
   etlplus.database.schema
   etlplus.file.core
   etlplus.file.enums
   etlplus.ops.extract
   etlplus.ops.load
   etlplus.ops.run
   etlplus.ops.transform
   etlplus.ops.validate
   etlplus.utils.data
   etlplus.utils.mapping
   etlplus.utils.numbers
   etlplus.utils.substitution
   etlplus.utils.text
   etlplus.workflow.dag
   etlplus.workflow.jobs
   etlplus.workflow.profile
